==> ruby-qte-devel-0.2.tar.gz: ruby-qte-devel-0.2/examples/xml/tagreader-with-features/tagreader.rb <==
=begin
/*
$Id: qt/examples/xml/tagreader-with-features/tagreader.cpp   2.2.4   edited 2001-01-22 $
*/
=end
require "qt2"
include Qt2
require "structureparser.rb"

    app = QApplication.new( [$0]+ARGV )

    xmlFile = File.new((ARGV.size == 1 ? ARGV[0]: "fnord.xml") , "r")  #QFilexmlFile( argc == 2 ? argv[1] : "fnord.xml" )
    source = QXmlInputSource.new
    source.setData(xmlFile.read )
    reader = QXmlSimpleReader.new

    container = QGrid.new( 3 )

    nameSpace = QListView.new( container, "table_namespace" )
    handlerNamespace = StructureParser.new
    handlerNamespace.setListView( nameSpace )
    reader.setContentHandler( handlerNamespace )
    reader.parse( source )

    namespacePrefix = QListView.new( container, "table_namespace_prefix" )
    handlerNamespacePrefix = StructureParser.new
    handlerNamespacePrefix.setListView( namespacePrefix )
    reader.setContentHandler( handlerNamespacePrefix )
    reader.setFeature( "http://xml.org/sax/features/namespaces", true )
    reader.setFeature( "http://xml.org/sax/features/namespace-prefixes", true )
    reader.parse( source )

    prefix = QListView.new( container, "table_prefix")
    handlerPrefix = StructureParser.new
    handlerPrefix.setListView( prefix )
    reader.setContentHandler( handlerPrefix )
    reader.setFeature( "http://xml.org/sax/features/namespaces", false )
    reader.setFeature( "http://xml.org/sax/features/namespace-prefixes", true )
    reader.parse( source )

    namespaceLabel = QLabel.new( (
                             "Default:\n"+ "http://xml.org/sax/features/namespaces: true\n"+ "http://xml.org/sax/features/namespace-prefixes: false\n"),
                             container )

    namespacePrefixLabel = QLabel.new((
                             "\n" + "http://xml.org/sax/features/namespaces: true\n"+ "http://xml.org/sax/features/namespace-prefixes: true\n"),
                             container )

    prefixLabel = QLabel.new((
                             "\n"+ "http://xml.org/sax/features/namespaces: false\n"+ "http://xml.org/sax/features/namespace-prefixes: true\n"),
                             container )


    app.setMainWidget( container )
    container.show()
    app.exec()

==> ruby-qte-devel-0.4.2.tar.gz: ruby-qte-devel-0.4.2/examples/xml/tagreader-with-features/tagreader.rb <==
=begin
/*
$Id: tagreader.rb,v 1.1.1.1 2002/12/22 14:19:57 taka-hr Exp $
*/
=end
require "qte"
include Qte
require "qpe"
include Qpe
require "structureparser.rb"

    app = QPEApplication.new( [$0]+ARGV )

    xmlFile = File.new((ARGV.size == 1 ? ARGV[0]: "fnord.xml") , "r")  #QFilexmlFile( argc == 2 ? argv[1] : "fnord.xml" )
    source = QXmlInputSource.new
    source.setData(xmlFile.read )
    reader = QXmlSimpleReader.new

    container = QGrid.new( 3 )

    nameSpace = QListView.new( container, "table_namespace" )
    handlerNamespace = StructureParser.new
    handlerNamespace.setListView( nameSpace )
    reader.setContentHandler( handlerNamespace )
    reader.parse( source )

    namespacePrefix = QListView.new( container, "table_namespace_prefix" )
    handlerNamespacePrefix = StructureParser.new
    handlerNamespacePrefix.setListView( namespacePrefix )
    reader.setContentHandler( handlerNamespacePrefix )
    reader.setFeature( "http://xml.org/sax/features/namespaces", true )
    reader.setFeature( "http://xml.org/sax/features/namespace-prefixes", true )
    reader.parse( source )

    prefix = QListView.new( container, "table_prefix")
    handlerPrefix = StructureParser.new
    handlerPrefix.setListView( prefix )
    reader.setContentHandler( handlerPrefix )
    reader.setFeature( "http://xml.org/sax/features/namespaces", false )
    reader.setFeature( "http://xml.org/sax/features/namespace-prefixes", true )
    reader.parse( source )

    namespaceLabel = QLabel.new( (
                             "Default:\n"+ "http://xml.org/sax/features/namespaces: true\n"+ "http://xml.org/sax/features/namespace-prefixes: false\n"),
                             container )

    namespacePrefixLabel = QLabel.new((
                             "\n" + "http://xml.org/sax/features/namespaces: true\n"+ "http://xml.org/sax/features/namespace-prefixes: true\n"),
                             container )

    prefixLabel = QLabel.new((
                             "\n"+ "http://xml.org/sax/features/namespaces: false\n"+ "http://xml.org/sax/features/namespace-prefixes: true\n"),
                             container )


    app.showMainWidget( container )
    app.exec()
